/*
 * Copyright (c) 2010-2012 The Amdatu Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.amdatu.web.rest;

import java.net.ConnectException;
import java.net.HttpURLConnection;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.concurrent.TimeUnit;

import junit.framework.TestCase;

import org.osgi.framework.BundleContext;
import org.osgi.framework.FrameworkUtil;

/**
 * Base for registration tests
 */
public abstract class RegistrationTestBase extends TestCase {

    public static final int HTTP_OK = 200;
    public static final int HTTP_FORBIDDEN = 403;
    public static final int HTTP_NOT_FOUND = 404;
    public static final int HTTP_INTERNAL_SERVER_ERROR = 500;

    public static final String PREFIX = "http://localhost:8080/";

    protected final BundleContext context = FrameworkUtil.getBundle(getClass()).getBundleContext();

    protected URL toURL(String url) throws MalformedURLException {
        if (!url.startsWith(PREFIX)) {
            url = PREFIX.concat(url);
        }
        return new URL(url);
    }

    protected int getResponseCode(String urlToRead) throws Exception {
        URL url = toURL(urlToRead);

        int rc = -1;
        int tries = 10;
        while (tries-- > 0 && rc < 0) {
            HttpURLConnection conn = null;

            try {
                conn = (HttpURLConnection) url.openConnection();
                rc = conn.getResponseCode();
            } catch (ConnectException e) {
                // Server not available yet, wait a little and try again...
                TimeUnit.MILLISECONDS.sleep(100L);
            } finally {
                if (conn != null) {
                    conn.disconnect();
                }
            }
        }
        return rc;
    }
}
